searchData={"items":[{"type":"module","title":"IExHistory2","doc":"Improved shell history with variable binding persistance.\n\n* Saves shell history between sessions.\n* Saves the shell variable bindings between VM restarts.\n* Ability to paste (most) terms into the shell.\n* Navigation keys allow history traversal where multi-line pastes require a single key up/down.\n* Shortcut functions permit search, pasting, re-evaluation and editing of items in history.\n* Editing can be done in-situ or in a text editor.\n* Shell variable bindings can be set/get outside of scope of the shell to assist in code debugging.\n* Can be enabled and state shared globally, or on individual shell sessions.\n\nSee section on `Initialization` and `Configuration` below.","ref":"IExHistory2.html"},{"type":"module","title":"Short-cut Functions - IExHistory2","doc":"iex> hl()                     - list the entire history.\n    \n    iex> hl(val)                  - list `val` entries from the start if val is positive, or from the end if negative.\n    \n    iex> hl(start, stop)          - list entries between `start` and `stop`.\n    \n    iex> hs(string)               - list entries that match all or part of the query string.\n\n    iex> hsi(string)              - case insensitive list entries that match all or part of the query string.\n\n    iex> hsa(string, dist \\ 80)  - closest match list of entries, e.g \"acr.to_str\" == \"Macro.to_string\"\n    \n    iex> hx(pos)                  - execute the expression at position `pos`.\n    \n    iex> hc(pos)                  - copy the expression at position pos to the shell.\n    \n    iex> he(pos)                  - edit the expression in a text editor.\n    \n    iex> hb()                     - show the current bindings.\n    \n    iex> hi()                     - summary\n\n**NOTE:** To use `he/1` the environment variable `EDITOR` must be set to point to your editor:\n\n    export EDITOR=\"vim\"\n\n#","ref":"IExHistory2.html#module-short-cut-functions"},{"type":"module","title":"Examples - IExHistory2","doc":"Simple listing of last 9 items:\n\n    iex hl(-9)  \n    239: 2023-11-28 19:27:13: Ecto.Repo.Registry.lookup(CollectionServer.Server.Repo)\n    240: 2023-11-28 19:27:27: Ecto.Repo.Registry.lookup(CollectionServer.Server.Repo.ReadOnly1)\n    241: 2023-11-28 19:30:57: Ecto.Repo.Registry.all_running\n    242: 2023-11-28 20:55:22: DevHelper.port_stats(peer_port: 5432, statistics: :send_cnt)\n    243: 2023-11-28 20:55:34: Process.whereis(CSAdmin) |> :sys.get_status()\n    244: 2023-11-28 20:55:53: Process.get(self())\n    245: 2023-11-28 20:55:57: Process.get(CSAdmin)\n    246: 2023-11-29 14:49:21: CollectionServer.Server.Repo.all(q1)\n    247: 2023-11-29 17:48:21: %CollectionServer.FileSystem.Node{}\n\nPartial match:\n\n    iex> hsa(\"Prcess.\")\n    7: 90% 2023-11-12 16:29:03: c = fn -> {dict, _} = Process.info(pid, :dictionary); dict[:request_user] end\n    8: 90% 2023-11-12 16:29:37: c = fn -> {dict, _} = Process.info(pid, :dictionary) end\n    20: 90% 2023-11-26 16:32:11: Process.get(:yyy)\n    21: 90% 2023-11-26 22:11:50: Process.info(pid(0,619,0))\n    208: 90% 2023-11-28 14:19:23: Process.whereis(CollectionServer.Server.ReadOnly1)\n    209: 90% 2023-11-28 14:19:34: Process.whereis(CollectionServer.Server.ReadOnly1) |> Process.info\n    210: 90% 2023-11-28 14:20:02: Process.whereis(CollectionServer.Server.ReadOnly1) |> Process.info() |> Keyword.get(:links)\n    211: 90% 2023-11-28 14:20:14: Process.whereis(CollectionServer.Server.Repo) |> Process.info() |> Keyword.get(:links)","ref":"IExHistory2.html#module-examples"},{"type":"module","title":"Special Functions - IExHistory2","doc":"iex> IExHistory2.add_binding(var, val)\n    \n    iex> IExHistory2.get_binding(var)\n    \n    iex> IExHistory2.clear_history()\n    \n    iex> IExHistory2.clear_bindings()\n        \nThe functions `IExHistory2.add_binding/2` and `IExHistory2.get_binding/1` allows variables\nto be set in a module that is invoked in the shell to be accessible in the shell and vice versa.\n    \n    defmodule VarTest do\n      \n      def get_me(val) do\n        if IExHistory2.get_binding(:path_to_use) == :path1 do\n          result = val + 100\n          IExHistory2.add_binding(:result_var, %{path: :path1, result: result})\n          result\n        else\n          result = val + 200\n          IExHistory2.add_binding(:result_var, %{path: :path2, result: result})\n          result\n        end\n      end\n      \n    end\n        \n    iex> path_to_use = :path1\n    :path1\n    iex> VarTest.get_me(50)\n    150\n    iex> result_var\n    %{path: :path1, result: 150}\n    \n    iex> path_to_use = :path2\n    :path2\n    iex> VarTest.get_me(50)\n    250\n    iex> result_var\n    %{path: :path2, result: 250}","ref":"IExHistory2.html#module-special-functions"},{"type":"module","title":"Navigation - IExHistory2","doc":"The application uses a different set of keys for navigation, and attempts to present multi-line \nterms and other items as a single line:\n\n    ctrl^u    - move up through history.\n    \n    ctrl^k    - move down through history.\n    \n    ctrl^y    - allows the currently displayed item to be modified.\n    \n    ctrl^e    - opens the currently displayed item in an editor.\n            \n    ctrl^[    - reset navigation, returns to the prompt.\n            \n**NOTE:** To use `ctrl^e` the environment variable `EDITOR` must be set to your editor:","ref":"IExHistory2.html#module-navigation"},{"type":"module","title":"Configuration - IExHistory2","doc":"The following options can be set either as a keyword list in `.iex.exs`.\n\n    [\n      scope: :local,\n      history_limit: :infinity,\n      import: true,\n      hide_history_commands: true,\n      prepend_identifiers: true,\n      command_display_width: int,\n      save_invalid_results: false,\n      key_buffer_history: true,\n      paste_eval_regex: [],\n      show_date: true,\n      save_bindings: true,\n      colors: [\n        index: :red,\n        date: :green,\n        command: :yellow,\n        label: :red,\n        variable: :green\n      ]\n    ]\n\nOr in `config/runtime.exs` if using Mix:\n\n    config :your_app, IExHistory2,\n      scope: :local,\n      history_limit: :infinity,\n      paste_eval_regex: [],\n      import: true,\n      ...\n \n#","ref":"IExHistory2.html#module-configuration"},{"type":"module","title":"Settings - IExHistory2","doc":"To import short-cut functions set `import:` to true.\n\n    import: true\n    \nOne current issue with the current shell is the inconsistent ability to paste large terms into\nthe shell. Terms such as process ids and references (`#PID<0.1234.0>`) cause the evaluator to fail. \nThe application will attempt to recognize such terms during evaluation, wrap them in quotes and attempt\nto re-evaluate. \n\nCurrently process ids, references, anonymous functions, ports and `#Ecto.Schema.Metadata` are \nsupported by default. Additional terms can be added:\n\n    paste_eval_regex: [\"#SpecialItem1\", \"#NewObject\"]\n        \nThis toggle true/false for calls to `IExHistory2.*` (and imports) from been saved.\n      \n    hide_history_commands: true \n    \nIf set to false, the default, commands that were evaluated incorrectly will not be saved.\n\n    save_invalid_results: false \n\nIf set to true will allow the user to scroll up (ctrl+u) or down (ctrl+k) through history.\n    \n    key_buffer_history: true\n    \nUnlike the standard up/down arrow history this is command based not line based. So pasting of a large term or source code will only require 1 up or down key.\n  \nIf this is enabled it will prepend identifiers when a call to `x = hx(val)` is issued.\n\n    prepend_identifiers: true\n    \nExample, enabled:\n \n    iex> time = Time.utc_now().second\n    14\n    iex> new_time = hx(1)\n    22\n\n    iex> new_time\n    22                  # New time is assigned to variable time\n    iex> time\n    13                  # However, the original date variable is unchanged\n\n    iex> hl()\n    1: 2021-09-01 17:13:13: time = Time.utc_now().second\n    2: 2021-09-01 17:13:22: new_time =  time = Time.utc_now().second    # We see the binding to new_time\n\nDisabled:\n\n    iex> time = Time.utc_now().second\n    43\n    iex> new_time = hx(1)\n    50\n\n    iex> new_time       # New time is assigned to variable time\n    50\n    iex> time\n    50                  # However, this time the original time variable has also changed\n\n    iex> hl()\n    1: 2021-09-01 17:17:43: time = Time.utc_now().second\n    2: 2021-09-01 17:17:50: time = Time.utc_now().second      # We do not see the binding to new_time\n\n\n`scope:` can be one of `:local, :global `or a `node name`\n\n* `:local` (the default) history will be active on all shells, even those that are remotely connected, but the history for each shell will be unique\n\n* `node_name`i.e. (e.g. `:mgr@localhost`) history will only be active on that shell\n\n* `:global` history will be shared between all shells. However the saving of variable bindings will be disabled along with the date/time in history\n\nIf a `scope` of `:global` is selected following kernel option must be set, either directly as VM options or via an environment variable:\n\n    export ERL_AFLAGS=\"-kernel shell_history enabled\"\n\n    --erl \"-kernel shell_history enabled\"","ref":"IExHistory2.html#module-settings"},{"type":"module","title":"Initialization - IExHistory2","doc":"#","ref":"IExHistory2.html#module-initialization"},{"type":"module","title":"Using `.iex.exs` - IExHistory2","doc":"It is recommended to configure and start using `.iex.exs`, for  example:\n\n    IExHistory2.initialize(history_limit: :infinity,\n                           scope: :local, \n                           paste_eval_regex: [\"#Extra\"], \n                           show_date: true, \n                           colors: [index: :red])\n\n#","ref":"IExHistory2.html#module-using-iex-exs"},{"type":"module","title":"As part of another application - IExHistory2","doc":"Add to `mix.exs` as a dependency: \n\n    {:iex_history2, \"~> 5.2\"}\n\nOr:\n\n    {:iex_history2, github: \"nhpip/iex_history2\", tag: \"5.2.0\"},\n        \nAdd the configuration to your application `config/runtime.exs`. For example:\n\n    config :iex_history2,\n      history_limit: 1234,\n      import: true,\n      scope: :local, \n      paste_eval_regex: [\"#Extra\"], \n      show_date: true, \n      colors: [index: :red]\n    \nWhen you connect your shell call `IExHistory2.initialize/0` (in `.iex.exs` or as a standalone call):\n\n    IExHistory2.initialize()\n\n**NOTE:** `:scope` of `:global` is not fully complete.","ref":"IExHistory2.html#module-as-part-of-another-application"},{"type":"function","title":"IExHistory2.add_binding/2","doc":"This helper function can be used when testing code (for example a module pasted into the shell).\nIt allows a variable to be set that will become available in the shell. For example:\n\n    defmodule VarTest do\n      def set_me(var) do\n        var = var * 2\n        IExHistory2.add_binding(:test_var, var)\n        var + 100\n      end\n    end\n\n    iex> VarTest.set_me(7)\n    \n    iex> test_var\n    14\n      \nThe variable can be represented as an atom or string.","ref":"IExHistory2.html#add_binding/2"},{"type":"function","title":"IExHistory2.add_binding/3","doc":"Experimental. Same as `add_binding/2`, but `name` is the registered name of a shell pid.\n\nSee `register/1`","ref":"IExHistory2.html#add_binding/3"},{"type":"function","title":"IExHistory2.clear/0","doc":"Clears the history and bindings. If `scope` is `:global`\n  the IEx session needs restarting for the changes to take effect.","ref":"IExHistory2.html#clear/0"},{"type":"function","title":"IExHistory2.clear_bindings/0","doc":"Clears the bindings.","ref":"IExHistory2.html#clear_bindings/0"},{"type":"function","title":"IExHistory2.clear_history/1","doc":"Clears the history only. If `scope` is `:global`\nthe IEx session needs restarting for the changes to take effect. If a value is passed it will clear that many history\nentries from start, otherwise the entire history is cleared.","ref":"IExHistory2.html#clear_history/1"},{"type":"function","title":"IExHistory2.configuration/0","doc":"Displays the current configuration.","ref":"IExHistory2.html#configuration/0"},{"type":"function","title":"IExHistory2.configure/2","doc":"Allows the following options to be changed, but not saved:\n    :show_date\n    :history_limit\n    :hide_history_commands,\n    :prepend_identifiers,\n    :save_bindings,\n    :command_display_width,\n    :save_invalid_results,\n    :key_buffer_history,\n    :colors\n\nExamples:\n    IExHistory2.configure(:colors, [index: :blue])\n    IExHistory2.configure(:prepend_identifiers, true)","ref":"IExHistory2.html#configure/2"},{"type":"function","title":"IExHistory2.default_config/0","doc":"Displays the default configuration.","ref":"IExHistory2.html#default_config/0"},{"type":"function","title":"IExHistory2.get_binding/1","doc":"This helper function can be used when testing code (for example a module pasted into the shell).\nIt allows a variable that is set in the shell to be available in a module under test. For example:\n\n    defmodule VarTest do\n      def get_me(val) do\n        if IExHistory2.get_binding(:path_to_use) == :path1 do\n          val + 100\n        else\n          val + 200\n        end\n      end     \n    end\n    \n    iex> path_to_use = :path1\n    :path1\n    iex> VarTest.get_me(50)\n    150\n    iex> path_to_use = :path2\n    :path2\n    iex> VarTest.get_me(50)\n    250\n    \nThe variable can be represented as an atom or string.","ref":"IExHistory2.html#get_binding/1"},{"type":"function","title":"IExHistory2.get_binding/2","doc":"Experimental. Same as `get_binding/2`, but `name` is the registered name of a shell pid.\n\nSee `register/1`","ref":"IExHistory2.html#get_binding/2"},{"type":"function","title":"IExHistory2.get_bindings/0","doc":"Returns the current shell bindings.","ref":"IExHistory2.html#get_bindings/0"},{"type":"function","title":"IExHistory2.hb/0","doc":"Show the variable bindings.","ref":"IExHistory2.html#hb/0"},{"type":"function","title":"IExHistory2.hc/1","doc":"Copies the command at index 'i' and pastes it to the shell.","ref":"IExHistory2.html#hc/1"},{"type":"function","title":"IExHistory2.he/1","doc":"","ref":"IExHistory2.html#he/1"},{"type":"function","title":"IExHistory2.hi/0","doc":"Show history information summary.","ref":"IExHistory2.html#hi/0"},{"type":"function","title":"IExHistory2.hl/0","doc":"Displays the entire history.","ref":"IExHistory2.html#hl/0"},{"type":"function","title":"IExHistory2.hl/1","doc":"Displays the entire history from the most recent entry back (negative number),\nor from the oldest entry forward (positive number)","ref":"IExHistory2.html#hl/1"},{"type":"function","title":"IExHistory2.hl/2","doc":"Specify a range, the atoms :start and :stop can also be used.","ref":"IExHistory2.html#hl/2"},{"type":"function","title":"IExHistory2.hs/1","doc":"Returns the list of expressions where all or part of the string matches.\n\nThe original expression does not need to be a string.","ref":"IExHistory2.html#hs/1"},{"type":"function","title":"IExHistory2.hsa/2","doc":"Like `hsa/1` a case insensitive search, but also adds a closeness element to the search.\n\nIt uses a combination of Myers Difference and Jaro Distance to get close to a match. The\nestimated closeness is indicated in the result with a default range of > 80%.\nThis can be set by the user.\n\nFor large histories this command may take several seconds.\n\nThe original expression does not need to be a string.","ref":"IExHistory2.html#hsa/2"},{"type":"function","title":"IExHistory2.hsi/1","doc":"A case insensitive search the list of expressions where all or part of the string matches.\n\nThe original expression does not need to be a string.","ref":"IExHistory2.html#hsi/1"},{"type":"function","title":"IExHistory2.hx/1","doc":"Invokes the command at index 'i'.","ref":"IExHistory2.html#hx/1"},{"type":"function","title":"IExHistory2.initialize/1","doc":"Initializes the IExHistory2 app. Takes the following parameters:\n\n  [\n    scope: :local,\n    history_limit: :infinity,\n    hide_history_commands: true,\n    prepend_identifiers: true,\n    key_buffer_history: true,\n    command_display_width: :int,\n    save_invalid_results: false,\n    show_date: true,\n    import: true,\n    paste_eval_regex: [],\n    save_bindings: true,\n    colors: [\n      index: :red,\n      date: :green,\n      command: :yellow,\n      label: :red,\n      variable: :green\n    ]\n  ]\n\nAlternatively a filename can be given that was saved with `IExHistory2.save_config()`\n\n`scope` can be one of `:local, :global` or a `node()` name","ref":"IExHistory2.html#initialize/1"},{"type":"function","title":"IExHistory2.is_enabled?/0","doc":"Returns `true` or `false` depending on if history is enabled.","ref":"IExHistory2.html#is_enabled?/0"},{"type":"function","title":"IExHistory2.load_config/1","doc":"Loads the current configuration to file `IExHistory2.save_config()`.\n\nNOTE: Not all options can be set during run-time. Instead pass the filename as a single argument to `IExHistory2.initialize()`","ref":"IExHistory2.html#load_config/1"},{"type":"function","title":"IExHistory2.register/1","doc":"Registers the shell under the name provided.","ref":"IExHistory2.html#register/1"},{"type":"function","title":"IExHistory2.save_config/1","doc":"Saves the current configuration to file.","ref":"IExHistory2.html#save_config/1"},{"type":"function","title":"IExHistory2.state/0","doc":"Displays the current state:\n\n    IExHistory2 version 2.0 is enabled:\n      Current history is 199 commands in size.\n      Current bindings are 153 variables in size.","ref":"IExHistory2.html#state/0"},{"type":"function","title":"IExHistory2.stop_clear/0","doc":"Clears the history and bindings then stops the service. If `scope` is ` :global` the IEx session needs restarting for the changes to take effect.","ref":"IExHistory2.html#stop_clear/0"},{"type":"function","title":"IExHistory2.unbind/1","doc":"Unbinds a variable or list of variables (specify variables as atoms, e.g. foo becomes :foo).","ref":"IExHistory2.html#unbind/1"}],"content_type":"text/markdown"}